@@ -1,9 +1,7 @@
 """Processing of systems."""
 
-from argparse import Namespace
-
 from homeinfotools.filetransfer.filetransfer import filetransfer
-from homeinfotools.multiprocessing import BaseWorker
+from homeinfotools.worker import BaseWorker
 
 
 __all__ = ['Worker']
@@ -12,7 +10,6 @@ __all__ = ['Worker']
 class Worker(BaseWorker):
     """Stored args and manager to process systems."""
 
-    @staticmethod
-    def run(system: int, args: Namespace) -> dict:
+    def run(self, system: int) -> dict:
         """Runs the worker."""
-        return {'rsync': filetransfer(system, args)}
+        return {'rsync': filetransfer(system, self.args)}
