@@ -2,11 +2,11 @@
 
 from json import dump
 from logging import basicConfig
+from multiprocessing import Manager, Pool
 from random import shuffle
 
 from homeinfotools.functions import get_log_level
 from homeinfotools.logging import LOG_FORMAT
-from homeinfotools.multiprocessing import multiprocess
 from homeinfotools.rpc.argparse import get_args
 from homeinfotools.rpc.worker import Worker
 
@@ -23,13 +23,18 @@ def main() -> int:
     if args.shuffle:
         shuffle(args.system)
 
+    results = Manager().dict()
+
     try:
-        result = multiprocess(Worker, args.system, args.processes, args=args)
+        with Pool(args.processes) as pool:
+            pool.map(
+                Worker(args, results), args.system, chunksize=args.chunk_size
+            )
     except KeyboardInterrupt:
         return 1
 
     if args.json is not None:
         with args.json.open('w') as file:
-            dump(dict(result), file, indent=2)
+            dump(dict(results), file, indent=2)
 
     return 0
